@@ -1,3 +1,5 @@
+from typing import Mapping
+
 import dask
 import dask.distributed
 from dagster import (
@@ -18,7 +20,7 @@ from dagster._core.execution.context.system import PlanOrchestrationContext
 from dagster._core.execution.plan.plan import ExecutionPlan
 from dagster._core.execution.retries import RetryMode
 from dagster._core.instance import DagsterInstance
-from dagster._utils import frozentags, iterate_with_context
+from dagster._utils import iterate_with_context
 
 # Dask resource requirements are specified under this key
 DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
@@ -121,7 +123,7 @@ def query_on_dask_worker(
     mode,
     instance_ref,
     known_state,
-):  # pylint: disable=unused-argument
+):
     """Note that we need to pass "dependencies" to ensure Dask sequences futures during task
     scheduling, even though we do not use this argument within the function.
     """
@@ -143,8 +145,8 @@ def query_on_dask_worker(
         )
 
 
-def get_dask_resource_requirements(tags):
-    check.inst_param(tags, "tags", frozentags)
+def get_dask_resource_requirements(tags: Mapping[str, str]):
+    check.mapping_param(tags, "tags", key_type=str, value_type=str)
     req_str = tags.get(DASK_RESOURCE_REQUIREMENTS_KEY)
     if req_str is not None:
         return _seven.json.loads(req_str)
@@ -169,7 +171,7 @@ class DaskExecutor(Executor):
         check.param_invariant(
             isinstance(plan_context.executor, DaskExecutor),
             "plan_context",
-            "Expected executor to be DaskExecutor got {}".format(plan_context.executor),
+            f"Expected executor to be DaskExecutor got {plan_context.executor}",
         )
 
         check.invariant(
@@ -259,10 +261,10 @@ class DaskExecutor(Executor):
                         query_on_dask_worker,
                         dependencies,
                         recon_pipeline,
-                        plan_context.pipeline_run,
+                        plan_context.dagster_run,
                         run_config,
                         [step.key],
-                        plan_context.pipeline_run.mode,
+                        plan_context.dagster_run.mode,
                         instance.get_ref(),
                         execution_plan.known_state,
                         key=dask_task_name,
